==> ph-collection-9.1.1-sources.jar: com/helger/collection/multimap/AbstractMultiConcurrentHashMapListBased.java <==
/**
 * Copyright (C) 2014-2018 Philip Helger (www.helger.com)
 * philip[at]helger[dot]com
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.helger.collection.multimap;

import java.util.Map;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.annotation.concurrent.ThreadSafe;

import com.helger.commons.collection.impl.ICommonsList;

/**
 * Abstract multi map based on {@link java.util.concurrent.ConcurrentHashMap}
 * and {@link ICommonsList} values.<br>
 * Important note: <code>null</code> keys are not allowed here!
 *
 * @author Philip Helger
 * @param <KEYTYPE>
 *        key type
 * @param <VALUETYPE>
 *        value type
 */
@ThreadSafe
public abstract class AbstractMultiConcurrentHashMapListBased <KEYTYPE, VALUETYPE> extends
                                                              AbstractMultiConcurrentHashMap <KEYTYPE, VALUETYPE, ICommonsList <VALUETYPE>>
                                                              implements IMultiMapListBased <KEYTYPE, VALUETYPE>
{
  public AbstractMultiConcurrentHashMapListBased ()
  {}

  public AbstractMultiConcurrentHashMapListBased (@Nonnull final KEYTYPE aKey, @Nullable final VALUETYPE aValue)
  {
    super (aKey, aValue);
  }

  public AbstractMultiConcurrentHashMapListBased (@Nonnull final KEYTYPE aKey,
                                                  @Nonnull final ICommonsList <VALUETYPE> aCollection)
  {
    super (aKey, aCollection);
  }

  public AbstractMultiConcurrentHashMapListBased (@Nullable final Map <? extends KEYTYPE, ? extends ICommonsList <VALUETYPE>> aCont)
  {
    super (aCont);
  }
}

==> ph-collection-9.2.0-sources.jar: com/helger/collection/multimap/AbstractMultiConcurrentHashMapListBased.java <==
/**
 * Copyright (C) 2014-2018 Philip Helger (www.helger.com)
 * philip[at]helger[dot]com
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.helger.collection.multimap;

import java.util.Map;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.annotation.concurrent.ThreadSafe;

import com.helger.commons.collection.impl.ICommonsList;

/**
 * Abstract multi map based on {@link java.util.concurrent.ConcurrentHashMap}
 * and {@link ICommonsList} values.<br>
 * Important note: <code>null</code> keys are not allowed here!
 *
 * @author Philip Helger
 * @param <KEYTYPE>
 *        key type
 * @param <VALUETYPE>
 *        value type
 */
@ThreadSafe
public abstract class AbstractMultiConcurrentHashMapListBased <KEYTYPE, VALUETYPE> extends
                                                              AbstractMultiConcurrentHashMap <KEYTYPE, VALUETYPE, ICommonsList <VALUETYPE>>
                                                              implements
                                                              IMultiMapListBased <KEYTYPE, VALUETYPE>
{
  public AbstractMultiConcurrentHashMapListBased ()
  {}

  public AbstractMultiConcurrentHashMapListBased (@Nonnull final KEYTYPE aKey, @Nullable final VALUETYPE aValue)
  {
    super (aKey, aValue);
  }

  public AbstractMultiConcurrentHashMapListBased (@Nonnull final KEYTYPE aKey,
                                                  @Nonnull final ICommonsList <VALUETYPE> aCollection)
  {
    super (aKey, aCollection);
  }

  public AbstractMultiConcurrentHashMapListBased (@Nullable final Map <? extends KEYTYPE, ? extends ICommonsList <VALUETYPE>> aCont)
  {
    super (aCont);
  }
}
